package com.muyu.business.controller;

import com.muyu.business.domain.Business;
import com.muyu.business.service.BusinessService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 企业的 BusinessController
 *
 * @author xiaohuang
 * on 2024/6/4
 */

@RestController
@RequestMapping("/business")
public class BusinessController extends BaseController {

    @Autowired
    private BusinessService businessService;


    /**
     * 查询企业列表
     */
    @GetMapping("/list")
    public Result<TableDataInfo<Business>> list(Business business){
        startPage();
        List<Business> list = businessService.selectBusinessList(business);
        return getDataTable(list);
    }


    /**
     * 导出企业列表
     */
    @Log(title = "企业", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Business business){
        List<Business> list = businessService.selectBusinessList(business);
        ExcelUtil<Business> util = new ExcelUtil<>(Business.class);
        util.exportExcel(response,list,"企业数据");
    }


    /**
     * 获取企业详细信息
     */
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id){
        return success(businessService.selectBusinessById(id));
    }


    /**
     * 新增企业
     */
    @Log(title = "企业",businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Business business){
        return toAjax(businessService.insertBusiness(business));
    }


    /**
     * 修改
     */
    @Log(title = "企业",businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Business business){
        return toAjax(businessService.updateBusiness(business));
    }


    /**
     * 删除
     */
    @Log(title = "企业",businessType = BusinessType.DELETE)
    @DeleteMapping("/{id}")
    public Result remove(@PathVariable Long[] ids){
        return toAjax(businessService.deleteBusinessByIds(ids));
    }

}
