package com.muyu.business.controller;

import com.muyu.business.domain.Entinfo;
import com.muyu.business.service.IEntinfoService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 多数据源 EntinfoController
 *
 * @author xiaohuang
 * on 2024/6/7
 */

@RestController
@RequestMapping("/entinfo")
public class EntinfoController extends BaseController {

    @Autowired
    private IEntinfoService entinfoService;

    /**
     * 查询多数据源列表
     */
//    @RequiresPermissions("system:entinfo:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Entinfo>> list(Entinfo entinfo)
    {
        startPage();
        List<Entinfo> list = entinfoService.selectEntinfoList(entinfo);
        return getDataTable(list);
    }

    /**
     * 导出多数据源列表
     */
//    @RequiresPermissions("system:entinfo:export")
    @Log(title = "多数据源", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Entinfo entinfo)
    {
        List<Entinfo> list = entinfoService.selectEntinfoList(entinfo);
        ExcelUtil<Entinfo> util = new ExcelUtil<Entinfo>(Entinfo.class);
        util.exportExcel(response, list, "多数据源数据");
    }

    /**
     * 获取多数据源详细信息
     */
//    @RequiresPermissions("system:entinfo:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(entinfoService.selectEntinfoById(id));
    }

    /**
     * 新增多数据源
     */
//    @RequiresPermissions("system:entinfo:add")
    @Log(title = "多数据源", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Entinfo entinfo)
    {
        return toAjax(entinfoService.insertEntinfo(entinfo));
    }

    /**
     * 修改多数据源
     */
//    @RequiresPermissions("system:entinfo:edit")
    @Log(title = "多数据源", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Entinfo entinfo)
    {
        return toAjax(entinfoService.updateEntinfo(entinfo));
    }

    /**
     * 删除多数据源
     */
//    @RequiresPermissions("system:entinfo:remove")
    @Log(title = "多数据源", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(entinfoService.deleteEntinfoByIds(ids));
    }
}

