package com.muyu.business.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.business.domain.Business;
import com.muyu.business.domain.Entinfo;
import com.muyu.business.mapper.BusinessMapper;
import com.muyu.business.service.BusinessService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.redis.service.RedisService;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.ProtocolException;
import java.net.URL;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * 企业 BusinessServiceImpl
 *
 * @author xiaohuang
 * on 2024/6/4
 */

@Service
public class BusinessServiceImpl extends ServiceImpl<BusinessMapper, Business> implements BusinessService {


    @Autowired
    private BusinessMapper businessMapper;


    @Autowired
    private RemoteUserService remoteUserService;

   @Autowired
   private RedisService redisService;






    @Override
    public Business selectBusinessById(Long id) {
        return businessMapper.selectBusinessById(id);
    }

    @Override
    public List<Business> selectBusinessList(Business business) {

        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = remoteUserService.selectByUserId(loginUser.getUserid());

        if (user.getUserType().equals("00")){
            return businessMapper.selectBusinessList(business);
        }
        business.setId(Long.valueOf(user.getUserType()));
        return businessMapper.selectBusinessList(business);
    }

    @Override
    public int insertBusiness(Business business) {

        business.setCreateTime(DateUtils.getNowDate());

        int i = businessMapper.insertBusiness(business);
        System.out.println(business);

       SysUser sysUser = SysUser.builder()
               .userName(business.getName())
               .password("admin123")
               .nickName(business.getName())
               .email(business.getBusinessEmail())
               .phonenumber(business.getBusinessPhone())
               .loginIp("111.229.102.61")
               .roleId(Long.valueOf(101))
               .userType(String.valueOf(business.getId()))
               .build();
        Result add = remoteUserService.add(sysUser);
        return i;

    }

    @Override
    public int updateBusiness(Business business) {

        business.setUpdateTime(DateUtils.getNowDate());
        httpConnectMysql(business);
        return businessMapper.updateBusiness(business);

    }

    @Autowired
    private EntinfoServiceImpl entinfoService;
    /**
     *
     * @ 判断redis是否存在端口号
     * @return
     */
    public void httpConnectMysql(Business business){
        redisService.deleteObject("entinfo");
        List<Entinfo> list = entinfoService.list();
        if (list.size()!=0){
            redisService.setCacheList("entinfo",list);
        }
        if (business.getBusinessStates().equals("2")){
            SysUser sysUser = remoteUserService.userById(business.getId());
            sysUser.setRoleId(Long.valueOf(2));
            remoteUserService.updateById(sysUser);
            Entinfo build = Entinfo.builder()
                    .entCode("test_" + business.getId())
                    .ip("192.168.120.128")
                    .port(Integer.valueOf(3306 + Integer.valueOf(String.valueOf(business.getId())))).build();
            Entinfo entinfo =entinfoService.selectEntinfo(build);
            if (entinfo == null){
                extracted(business);
            }
        }

    }



  private void extracted(Business business){
        String postUrl = "http://192.168.120.128/webhook/%E6%96%B0%E5%BB%BAmysql%E6%9C%8D%E5%8A%A1";
        HashMap<String, String> hashMap = new HashMap<>();
        hashMap.put("businessId",business.getId() + business.getName());
        hashMap.put("mysqlPort",String.valueOf(3306 + business.getId()));
      String json = JSON.toJSONString(hashMap);

      // 3.创建链接与设置连接参数
      URL urlObj = null;

      try {
          urlObj = new URL(postUrl);
          HttpURLConnection httpConn = (HttpURLConnection) urlObj.openConnection();
          httpConn.setRequestMethod("POST");
          httpConn.setRequestProperty("Charset","UTF-8");

          //post请求且json数据,必须设置
          httpConn.setRequestProperty("Content-Type","application/json");

          //打开输出流,默认false
          httpConn.setDoOutput(true);

          //4.从httpURLConnection获取输出流和写数据
          OutputStream oStream = httpConn.getOutputStream();
          oStream.write(json.getBytes());
          oStream.flush();

      } catch (MalformedURLException e) {
          throw new RuntimeException(e);
      }
  }




    @Override
    public int deleteBusinessByIds(Long[] ids) {
        return businessMapper.deleteBusinessByIds(ids);
    }

    @Override
    public int deleteBusinessById(Long id) {
        return businessMapper.deleteBusinessById(id);
    }
}
