package com.muyu.vehicle.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.vehicle.domain.Fence;
import com.muyu.vehicle.service.IFenceService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
 * 围栏 中心 Controller BingRui.Hou
 *
 * @author
 * @date 2024-05-31
 */
@RestController
@RequestMapping("/fence")
@Log4j2
public class FenceController extends BaseController
{
    @Autowired
    private IFenceService fenceService;

    /**
     * 查询围栏列表
     */
//    @RequiresPermissions("system:fence:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Fence>> list(Fence fence)
    {
        startPage();
        List<Fence> list = fenceService.selectFenceList(fence);
        log.info("list:{}",list);
        return getDataTable(list);
    }

    /**
     * 导出围栏列表
     */
//    @RequiresPermissions("system:fence:export")
    @Log(title = "围栏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fence fence)
    {
        List<Fence> list = fenceService.selectFenceList(fence);
        ExcelUtil<Fence> util = new ExcelUtil<Fence>(Fence.class);
        util.exportExcel(response, list, "围栏数据");
    }

    /**
     * 获取围栏详细信息
     */
//    @RequiresPermissions("system:fence:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(fenceService.selectFenceById(id));
    }

    /**
     * 新增围栏
     */
//    @RequiresPermissions("system:fence:add")
    @Log(title = "围栏", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Fence fence)
    {
        return toAjax(fenceService.insertFence(fence));
    }

    /**
     * 修改围栏
     */
//    @RequiresPermissions("system:fence:edit")
    @Log(title = "围栏", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Fence fence)
    {
        return toAjax(fenceService.updateFence(fence));
    }

    /**
     * 删除围栏
     */
//    @RequiresPermissions("system:fence:remove")
    @Log(title = "围栏", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(fenceService.deleteFenceByIds(ids));
    }
}
