package com.muyu.vehicle.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.vehicle.service.IGroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.vehicle.domain.Group;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
/**
 * 围栏组Controller

 * @date 2024-06-02
 */
@RestController
@RequestMapping("/group")
public class GroupController extends BaseController
{
    @Autowired
    private IGroupService groupService;

    /**
     * 查询围栏组列表
     */
//    @RequiresPermissions("system:group:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Group>> list(Group group)
    {
        startPage();
        List<Group> list = groupService.selectGroupList(group);
        return getDataTable(list);
    }

    /**
     * 导出围栏组列表
     */
//    @RequiresPermissions("system:group:export")
    @Log(title = "围栏组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Group group)
    {
        List<Group> list = groupService.selectGroupList(group);
        ExcelUtil<Group> util = new ExcelUtil<Group>(Group.class);
        util.exportExcel(response, list, "围栏组数据");
    }

    /**
     * 获取围栏组详细信息
     */
//    @RequiresPermissions("system:group:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(groupService.selectGroupById(id));
    }

    /**
     * 新增围栏组
     */
//    @RequiresPermissions("system:group:add")
    @Log(title = "围栏组", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Group group)
    {
        return toAjax(groupService.insertGroup(group));
    }

    /**
     * 修改围栏组
     */
//    @RequiresPermissions("system:group:edit")
    @Log(title = "围栏组", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Group group)
    {
        return toAjax(groupService.updateGroup(group));
    }

    /**
     * 删除围栏组
     */
//    @RequiresPermissions("system:group:remove")
    @Log(title = "围栏组", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(groupService.deleteGroupByIds(ids));
    }
}
