package com.muyu.vehicle.controller;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.vehicle.domain.Vehicle;
import com.muyu.vehicle.service.IVehicleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 车辆录入Controller
 *
 *
 * @date 2024-05-27
 */
@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController
{
    @Autowired
    private IVehicleService vehicleService;

    /**
     * 查询车辆录入列表
     */
//    @RequiresPermissions("system:vehicle:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(Vehicle vehicle)
    {
        startPage();
        List<Vehicle> list = vehicleService.selectVehicleList(vehicle);
        return getDataTable(list);
    }

    /**
     * 导出车辆录入列表
     */
//    @RequiresPermissions("system:vehicle:export")
//    @Log(title = "车辆录入", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, Vehicle vehicle)
//    {
//        List<Vehicle> list = vehicleService.selectVehicleList(vehicle);
//        ExcelUtil<Vehicle> util = new ExcelUtil<Vehicle>(Vehicle.class);
//        util.exportExcel(response, list, "车辆录入数据");
//    }

    /**
     * 获取车辆录入详细信息
     */
//    @RequiresPermissions("system:vehicle:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(vehicleService.selectVehicleById(id));
    }

    /**
     * 新增车辆录入
     */
//    @RequiresPermissions("system:vehicle:add")
    @Log(title = "车辆录入", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Vehicle vehicle)
    {
        return toAjax(vehicleService.insertVehicle(vehicle));
    }

    /**
     * 修改车辆录入
     */
//    @RequiresPermissions("system:vehicle:edit")
    @Log(title = "车辆录入", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Vehicle vehicle)
    {
        return toAjax(vehicleService.updateVehicle(vehicle));
    }

    /**
     * 删除车辆录入
     */
//    @RequiresPermissions("system:vehicle:remove")
    @Log(title = "车辆录入", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(vehicleService.deleteVehicleByIds(ids));
    }
}
