package com.muyu.vehicle.datasource.util;

import com.alibaba.druid.pool.DruidDataSource;

import com.muyu.vehicle.datasource.ManyDataSource;
import com.muyu.vehicle.datasource.config.factory.DruidDataSourceFactory;
import com.muyu.vehicle.datasource.config.role.DynamicDataSource;
import com.muyu.vehicle.datasource.domain.DataSourceInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Map;

/**
 * @Description:   数据源工具类
 * @Author Dongzl
 * @Date 2022/8/18 17:20
 *
 */
@Slf4j
@Component
public class DataSourceService {

    @Autowired
    private ManyDataSource druidConfig;

    @Autowired
    private DruidDataSourceFactory druidDataSourceFactory;

    @Resource
    private DynamicDataSource dynamicDataSource;

    public void addDataSource(DataSourceInfo dataSourceInfo){
        addDefineDynamicDataSource(druidDataSourceFactory.create(dataSourceInfo), dataSourceInfo.getKey());
    }

    /**
     * @Description: 将新增的数据源加入到备份数据源map中
     * @Author Dongzl
     */
    public void addDefineDynamicDataSource(DruidDataSource druidDataSource, String dataSourceName){
        Map<Object, Object> defineTargetDataSources = dynamicDataSource.getDefineTargetDataSources();
        defineTargetDataSources.put(dataSourceName, druidDataSource);
        dynamicDataSource.setTargetDataSources(defineTargetDataSources);
        dynamicDataSource.afterPropertiesSet();
    }
}
