package com.muyu.vehicle.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.muyu.common.core.utils.DateUtils;
import com.muyu.vehicle.domain.Fence;
import com.muyu.vehicle.mapper.FenceMapper;
import com.muyu.vehicle.service.IFenceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 围栏Service业务层处理
 *
 * @author muyu
 * @date 2024-05-31
 */
@Service
public class FenceServiceImpl extends ServiceImpl<FenceMapper, Fence>
        implements IFenceService
{
    @Autowired
    private FenceMapper fenceMapper;

    /**
     * 查询围栏
     *
     * @param id 围栏主键
     * @return 围栏
     */
    @Override
    public Fence selectFenceById(Long id)
    {
        return fenceMapper.selectFenceById(id);
    }

    /**
     * 查询围栏列表
     *
     * @param fence 围栏
     * @return 围栏
     */
    @Override
    public List<Fence> selectFenceList(Fence fence)
    {
        return fenceMapper.selectFenceList(fence);
    }

    /**
     * 新增围栏
     *
     * @param fence 围栏
     * @return 结果
     */
    @Override
    public int insertFence(Fence fence)
    {
//        String jsonString = JSON.toJSONString(fence.getPath());
        String string = fence.getPath().toString();
        fence.setFenceLongitudeLatitude(string);
        fence.setCreateTime(DateUtils.getNowDate());
        return fenceMapper.insertFence(fence);
    }

    /**
     * 修改围栏
     *
     * @param fence 围栏
     * @return 结果
     */
    @Override
    public int updateFence(Fence fence)
    {
        fence.setUpdateTime(DateUtils.getNowDate());
        return fenceMapper.updateFence(fence);
    }

    /**
     * 批量删除围栏
     *
     * @param ids 需要删除的围栏主键
     * @return 结果
     */
    @Override
    public int deleteFenceByIds(Long[] ids)
    {
        return fenceMapper.deleteFenceByIds(ids);
    }

    /**
     * 删除围栏信息
     *
     * @param id 围栏主键
     * @return 结果
     */
    @Override
    public int deleteFenceById(Long id)
    {
        return fenceMapper.deleteFenceById(id);
    }
}
