package com.muyu.vehicle.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.muyu.common.core.utils.DateUtils;
import com.muyu.vehicle.domain.Group;
import com.muyu.vehicle.mapper.GroupMapper;
import com.muyu.vehicle.service.IGroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 围栏组Service业务层处理
 *
 * @author muyu
 * @date 2024-06-02
 */
@Service
public class GroupServiceImpl extends ServiceImpl<GroupMapper, Group>
        implements IGroupService
{
    @Autowired
    private GroupMapper groupMapper;

    /**
     * 查询围栏组
     *
     * @param id 围栏组主键
     * @return 围栏组
     */
    @Override
    public Group selectGroupById(Long id)
    {
        return groupMapper.selectGroupById(id);
    }

    /**
     * 查询围栏组列表
     *
     * @param group 围栏组
     * @return 围栏组
     */
    @Override
    public List<Group> selectGroupList(Group group)
    {
        return groupMapper.selectGroupList(group);
    }

    /**
     * 新增围栏组
     *
     * @param group 围栏组
     * @return 结果
     */
    @Override
    public int insertGroup(Group group)
    {
        group.setCreateTime(DateUtils.getNowDate());
        return groupMapper.insertGroup(group);
    }

    /**
     * 修改围栏组
     *
     * @param group 围栏组
     * @return 结果
     */
    @Override
    public int updateGroup(Group group)
    {
        return groupMapper.updateGroup(group);
    }

    /**
     * 批量删除围栏组
     *
     * @param ids 需要删除的围栏组主键
     * @return 结果
     */
    @Override
    public int deleteGroupByIds(Long[] ids)
    {
        return groupMapper.deleteGroupByIds(ids);
    }

    /**
     * 删除围栏组信息
     *
     * @param id 围栏组主键
     * @return 结果
     */
    @Override
    public int deleteGroupById(Long id)
    {
        return groupMapper.deleteGroupById(id);
    }
}
