package com.muyu.vehicle.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteFileService;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.vehicle.domain.Vehicle;
import com.muyu.vehicle.mapper.VehicleMapper;
import com.muyu.vehicle.service.IVehicleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 车辆录入Service业务层处理
 *
 * @author muyu
 * @date 2024-05-27
 */
@Service
public class VehicleServiceImpl  extends ServiceImpl<VehicleMapper, Vehicle>
        implements IVehicleService
{
    @Autowired
    private VehicleMapper vehicleMapper;

    @Autowired
    private RemoteUserService remoteUserService;

//    @Autowired
//    private IBusinessService businessService;

    @Autowired
    private RemoteFileService remoteFileService;

    /**
     * 查询车辆录入
     *
     * @param id 车辆录入主键
     * @return 车辆录入
     */
    @Override
    public Vehicle selectVehicleById(Long id)
    {
        return vehicleMapper.selectVehicleById(id);
    }


    /**
     * 查询车辆录入列表
     *
     * @param vehicle 车辆录入
     * @return 车辆录入
     */
    @Override
    public List<Vehicle> selectVehicleList(Vehicle vehicle)
    {

        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = remoteUserService.selectByUserId(loginUser.getUserid());
        if (user.getUserType().equals("00")) {
            return vehicleMapper.selectVehicleList(vehicle);
        }
        vehicle.setBusinessId(Long.valueOf(user.getUserType()));
        List<Vehicle> vehicles = vehicleMapper.selectVehicleList(vehicle);


        return vehicles;
    }

    /**
     * 新增车辆录入
     *
     * @param vehicle 车辆录入
     * @return 结果
     */
    @Override
    public int insertVehicle(Vehicle vehicle)
    {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = remoteUserService.selectByUserId(loginUser.getUserid());
        vehicle.setBusinessId(Long.valueOf(user.getUserType()));
        vehicle.setCreateTime(DateUtils.getNowDate());
        return vehicleMapper.insertVehicle(vehicle);
    }

    /**
     * 修改车辆录入
     *
     * @param vehicle 车辆录入
     * @return 结果
     */
    @Override
    public int updateVehicle(Vehicle vehicle)
    {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        SysUser user = remoteUserService.selectByUserId(loginUser.getUserid());
        vehicle.setBusinessId(Long.valueOf(user.getUserType()));
        vehicle.setCreateTime(DateUtils.getNowDate());
        vehicle.setUpdateTime(DateUtils.getNowDate());
        return vehicleMapper.updateVehicle(vehicle);
    }

    /**
     * 批量删除车辆录入
     *
     * @param ids 需要删除的车辆录入主键
     * @return 结果
     */
    @Override
    public int deleteVehicleByIds(Long[] ids)
    {
        return vehicleMapper.deleteVehicleByIds(ids);
    }

    /**
     * 删除车辆录入信息
     *
     * @param id 车辆录入主键
     * @return 结果
     */
    @Override
    public int deleteVehicleById(Long id)
    {
        return vehicleMapper.deleteVehicleById(id);
    }

}
